@@ -1,10 +1,9 @@
 package Datahub::Factory::Exporter::Arthub;
 
-use strict;
-use warnings;
-
 use Datahub::Factory::Sane;
 
+our $VERSION = '0.91';
+
 use Lido::XML;
 use Moo;
 use Catmandu;
