@@ -1,12 +1,12 @@
 package Datahub::Factory::Importer::VKC;
 
-use strict;
-use warnings;
+use Datahub::Factory::Sane;
 
-our $VERSION = '0.9';
+our $VERSION = '0.91';
 
 use Moo;
 use Catmandu;
+use namespace::clean;
 
 with 'Datahub::Factory::Importer';
 
@@ -78,4 +78,4 @@ L<Datahub::Factory>
 L<Datahub::Factory::CollectiveAccess>
 L<Catmandu>
 
-=cut
\ No newline at end of file
+=cut
