@@ -1,12 +1,13 @@
 package Datahub::Factory::Module::PID::CloudFiles;
 
-use strict;
-use warnings;
+use Datahub::Factory::Sane;
+
+our $VERSION = '0.91';
 
 use Moo;
 use Catmandu;
-
 use WebService::Rackspace::CloudFiles;
+use namespace::clean;
 
 with 'Datahub::Factory::Module::PID::File';
 
@@ -45,4 +46,4 @@ sub get_object {
     return sprintf('/tmp/%s', $file_name);
 }
 
-1;
\ No newline at end of file
+1;
